%define anolis_release 3
%bcond_without zstd

Summary:        A library for making, reading and applying deltarpm packages
Name:           drpm
Version:        0.5.1
Release:        %{anolis_release}%{dist}
# the entire source code is LGPLv2+
# except src/drpm_diff.c and src/drpm_search.c which are BSD
License:        LGPLv2+ and BSD
URL:            https://github.com/rpm-software-management/%{name}
Source:         %{url}/releases/download/%{version}/%{name}-%{version}.tar.bz2

BuildRequires:  cmake >= 2.8.5 gcc gcc-c++

BuildRequires:  rpm-devel
BuildRequires:  openssl-devel
BuildRequires:  zlib-devel
BuildRequires:  bzip2-devel
BuildRequires:  xz-devel
%if %{with zstd}
BuildRequires:  pkgconfig(libzstd)
%endif

BuildRequires:  pkgconfig doxygen

BuildRequires:  libcmocka-devel >= 1.0
%ifarch %{ix86} x86_64 aarch64
BuildRequires:  valgrind
%endif

%description
Delta RPM (drpm) is a library used to create, read, and apply delta RPM (dRPM)
packages. Delta RPM is a technique used in Linux distributions to reduce the
amount of data that needs to be transferred during software updates. A delta
RPM package contains the difference between two software packages - the
original and the updated version.

The drpm library provides a fast and efficient way to create the delta RPM
packages, which can then be used to update the software in the system. The
library also allows users to read and apply the delta RPM packages, which can
help reduce the amount of data needed to download during software updates,
saving both time and bandwidth.

%package devel
Summary:        C interface for the drpm library
Requires:       %{name} = %{version}-%{release}

%description devel
The drpm-devel package provides a C interface (drpm.h) for the drpm library.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build
%cmake \
    -DWITH_ZSTD:BOOL=%{?with_zstd:ON}%{!?with_zstd:OFF} \
    -DHAVE_LZLIB_DEVEL:BOOL=OFF
%cmake_build
%cmake_build --target doc

%install
%cmake_install

%generate_compatibility_deps

%check
%ctest

%files
%license COPYING LICENSE.BSD
%dir %{abidir}
%{_libdir}/lib%{name}.so.*
%{abidir}/libdrpm.dump

%files devel
%{_libdir}/lib%{name}.so
%{_includedir}/%{name}.h
%{_libdir}/pkgconfig/%{name}.pc

%files doc
%doc %{_vpath_builddir}/doc/html/

%changelog
* Thu Apr 13 2023 Kun(llfl) <llfl@linux.alibaba.com> - 0.5.1-3
- optimize spec file

* Mon Feb 13 2023 happy_orange <songnannan@linux.alibaba.com> - 0.5.1-2
- add doc package and abi info

* Tue Apr 12 2022 Zhongling He <zhonglingh@linux.alibaba.com> 0.5.1-1
- Init package from upstream v0.5.1
